Description Usage Arguments Value References Examples
Estimate a signal tensor and permutation from a noisy and incomplete data tensor using Borda count estimation method.
1 | Borda_count(A, l, kvec, sym = FALSE)
|
A |
A given (possibly noisy and incomplete) data tensor. Missing value should be encoded as |
l |
Degree of polynomial approximation. |
kvec |
A vector of the number of groups for each mode. |
sym |
Boolean variables representing symmetricity of the signal tensor. Non-symmetric tensor ( |
The returned object is a list of components.
Theta - An estimated signal tensor based on Borda count estimation.
permutation - An estimated permutation based on Borda count estimation.
C. Lee and M. Wang. Smooth tensor estimation with unknown permutations. arXiv:2111.04681, 2021.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 | # Generate the noisy observation from smooth tensor and permutation
d = 20
sim1 = simulation(d,mode = 1)
signal_T = sim1$signal
observe_T = sim1$observe
permutation = sim1$permutation
# Estimate signal tensor and permutation
kvec = c(3,3,3)
result = Borda_count(observe_T,2,kvec,sym = TRUE)
# Calculate MSE
hatTheta = result$Theta
mean((hatTheta-signal_T)^2)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.