Description Usage Arguments Value References Examples
Estimate a permuted signal tensor from a noisy data tensor based on the least squares estimation with constant block approximation.
1 |
A |
A given noisy data tensor. |
kvec |
A vector of the number of groups for each mode. |
sym |
Boolean variables representing symmetricity of the signal tensor. Non-symmetric tensor ( |
mode |
An integer from 1 to 3 representing a type of methods for estimating the clustering functions. Higher-order spectral clustering method is default. |
An estimated permuted signal tensor based on the least squares estimation.
C. Gao, Y. Lu, and H. H. Zhou. Rate-optimal graphon estimation. The Annals of Statistics, 2015.
K. Balasubramanian. Nonparametric modeling of higher-order interactions via hypergraphons. Journal of Machine Learning Research, 2021.
R. Han, Y. Luo, M. Wang, and A. R. Zhang. Exact clustering in tensor block model: Statistical optimality and computational limit. arXiv:2012.09996, 2020.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 | # Generate the noisy observation from smooth tensor and permutation
d = 20
sim1 = simulation(d, mode = 1)
signal_T = sim1$signal
observe_T = sim1$observe
permutation = sim1$permutation
psignal_T = signal_T[permutation,permutation,permutation]
# Estimate permuted signal tensor
kvec = c(10,10,10)
hatpTheta = LSE(observe_T,kvec,sym = TRUE)
# Calculate MSE
mean((hatpTheta-psignal_T)^2)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.