Description Usage Arguments Value References Examples
Estimate a permuted signal tensor from a noisy data tensor using spectral method, which performs universal singualr value thresholding on the unfolded tensor.
1 |
A |
A given noisy data tensor. |
row_idx |
The indices of the modes that map onto the row space |
col_idx |
The indices of the modes that map onto the column space |
threshold |
A threshold to disregard singular values. Default value is the square root of unfolded matrix dimension. |
An estimated permuted signal tensor based on Spectral method.
J. Xu. Rates of convergence of spectral methods for graphon estimation. International Conference on Machine Learning, 2018.
C. Lee and M. Wang. Smooth tensor estimation with unknown permutations. arXiv:2111.04681, 2021.
1 2 3 4 5 6 7 8 9 10 11 12 13 | # Generate the noisy observation from smooth tensor and permutation
d = 20
sim1 = simulation(d,mode = 1)
signal_T = sim1$signal
observe_T = sim1$observe
permutation = sim1$permutation
psignal_T = signal_T[permutation,permutation,permutation]
# Estimate permuted signal tensor
hatpTheta = Spectral(observe_T,1,c(2,3))
# Calculate MSE
mean((hatpTheta-psignal_T)^2)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.