simulation_bin: Generate a symmetric binary tensor from the probability...

Description Usage Arguments Value References Examples

View source: R/smoothT.R

Description

Generate a symmetric binary tensor from the probability tensor and permutation. Users can select one of 5 different smooth probability tensor generated from functions specified in Table 4 of the reference given below.

Usage

1

Arguments

d

Dimension of a tensor to be generated.

mode

An integer from 1 to 5 corresponding to models specified. Default model is 1.

Value

The returned object is a list of components.

signal - A true probability tensor generated from a function specified.

observe - A binary tensor generated by Bernoulli trials given the probability tensor and permutation.

permutation - A true permutation.

References

C. Lee and M. Wang. Smooth tensor estimation with unknown permutations. arXiv:2111.04681, 2021.

Examples

1
2
3
4
5
6
d = 20
# Generate 20 by 20 by 20 binary-valued tensor generated from model 1
sim1 = simulation_bin(d, mode = 1)
observed_tensor = sim1$observe
signal_tensor = sim1$signal
permutation = sim1$permutation

SmoothTensor documentation built on Nov. 16, 2021, 9:08 a.m.