Description Usage Arguments Value References Examples
Generate a symmetric binary tensor from the probability tensor and permutation. Users can select one of 5 different smooth probability tensor generated from functions specified in Table 4 of the reference given below.
1 | simulation_bin(d, mode = 1)
|
d |
Dimension of a tensor to be generated. |
mode |
An integer from 1 to 5 corresponding to models specified. Default model is 1. |
The returned object is a list of components.
signal - A true probability tensor generated from a function specified.
observe - A binary tensor generated by Bernoulli trials given the probability tensor and permutation.
permutation - A true permutation.
C. Lee and M. Wang. Smooth tensor estimation with unknown permutations. arXiv:2111.04681, 2021.
1 2 3 4 5 6 | d = 20
# Generate 20 by 20 by 20 binary-valued tensor generated from model 1
sim1 = simulation_bin(d, mode = 1)
observed_tensor = sim1$observe
signal_tensor = sim1$signal
permutation = sim1$permutation
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.